@@ -3,7 +3,7 @@ import os
 import yaml
 import git
 
-## source vars
+## global vars
 
 path = os.path.expanduser('~')
 
@@ -18,24 +18,27 @@ git_def_path = get_git_root(os.getcwd())
 
 git_path = git_def_path
 
-filename = 'droughty_project.yaml'
+## profile vars 
 
-profile_filename = 'profile.yaml'
+filename = 'profile.yaml'
+
+profile_pass = os.path.join(git_path,filename)
+
+with open(profile_pass) as f:
+    lookml_config = yaml.load(f, Loader=yaml.FullLoader)
+
+profile_key = list(lookml_config.keys())
+
+## project vars 
+
+filename = 'droughty_project.yaml'
 
 droughty_project = os.path.join(git_path,filename)
 
 with open(droughty_project) as f:
-    enviroment_project = yaml.load(f, Loader=yaml.FullLoader)
+    environment_project = yaml.load(f, Loader=yaml.FullLoader)
 
-droughty_profile = os.path.join(git_path,profile_filename)
-
-with open(droughty_profile) as f:
-    lookml_config = yaml.load(f, Loader=yaml.FullLoader)    
-
-project_value = list(enviroment_project.values())
-profile_key = list(lookml_config.keys())
-
-for key,value in enviroment_project.items():
+for key,value in environment_project.items():
     
     if key == 'profile':
 
@@ -45,17 +48,18 @@ for key,value in enviroment_project.items():
 
             warehouse_name =  lookml_config[value]['warehouse_name']
             project_name =  lookml_config[value]['project_name']
-            enviroment_project = enviroment_project['profile']
+            environment_profile = environment_project['profile']
             
 
             ## big_query vars
 
             if warehouse_name == 'big_query':
 
-                service_account_path = ['DBT_GOOGLE_BIGQUERY_KEYFILE_DEV']
+                #service_account_path = os.environ.get("DBT_GOOGLE_BIGQUERY_KEYFILE_DEV")
+                service_account_path = "./droughty-service-account.json"
 
                 warehouse_name =  lookml_config[value]['warehouse_name']
-                project_name =  ['DBT_GOOGLE_PROJECT_DEV']
+                project_name =  os.environ.get("DBT_GOOGLE_PROJECT_DEV")
 
                 service_account = service_account.Credentials.from_service_account_file(
                     service_account_path,
